==> kadu_0.6.6~rc1.orig.tar.bz2: kadu-0.6.6-rc1/modules/sms/translations/sms_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Nick SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Używaj wbudowanej aplikacji SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Własna aplikacja SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Używaj własnych argumentów SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Argumenty SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Bramki</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>Bramka SMS Era</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorowana</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID użytkownika (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check this box if your sms application doesn&apos;t understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaznacz to okienko jeżeli aplikacja SMS nie rozpoznaje argumentów: numer &amp;wiadomość&amp;
Argumenty powinny być oddzielone spacjami. %k jest zamieniane na numer, %m na wiadomość</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Wyślij SMSa...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Wybierz automatycznie</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Operator GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Zapisz SMS w historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Nie określono aplikacji SMS. Sprawdź konfigurację</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Problem z uruchomieniem programu do wysyłania SMS</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation>Nie udało się pobrać wymaganego tokena</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation>Numer telefonu jest nieprawidłowy</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Pole &quot;Podpis&quot; nie może być puste</translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatyczny wybór bramki jest niedostępny. Proszę wybierz bramkę SMS.</translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
        <translation>Trwa wysyłanie SMSa.</translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation>SMS został pomyślnie wysłany</translation>
    </message>
</context>
</TS>

==> kadu_0.9.1.orig.tar.bz2: kadu-0.9.1/modules/sms/translations/sms_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Nick</source>
		<translation>Pseudonim</translation>
    </message>
    <message>
        <source>SMS Nick</source>
		<translation>Pseudonim SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Używaj wbudowanej aplikacji SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Własna aplikacja SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Używaj własnych argumentów SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Argumenty SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Bramki</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>Bramka SMS Era</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorowana</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID użytkownika (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check this box if your sms application doesn&apos;t understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaznacz to okienko jeżeli aplikacja SMS nie rozpoznaje argumentów: numer &amp;wiadomość&amp;
Argumenty powinny być oddzielone spacjami. %k jest zamieniane na numer, %m na wiadomość</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
		<translation>Wyślij SMS-a...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Wybierz automatycznie</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Operator GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Zapisz SMS w historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Nie określono aplikacji SMS. Sprawdź konfigurację</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Problem z uruchomieniem programu do wysyłania SMS</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation>Nie udało się pobrać wymaganego tokena</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation>Numer telefonu jest nieprawidłowy</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Pole &quot;Podpis&quot; nie może być puste</translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatyczny wybór bramki jest niedostępny. Proszę wybierz bramkę SMS.</translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
		<translation>Trwa wysyłanie SMS-a.</translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation>SMS został pomyślnie wysłany</translation>
    </message>
</context>
</TS>
